#!/usr/bin/env perl

use strict;
use warnings;
use Net::Frame::Layer::IGMP qw/:consts/;
use Net::Frame::Layer::IGMP::v3Report qw/:consts/;
use Net::Frame::Layer::IPv4 qw/:consts/;
use Net::Frame::Simple;
use Net::Write::Layer qw/:constants/;
use Net::Write::Layer3;
use Sys::HostIP;

my $hdmi_dev = 0+$ARGV[0];
my $multicast_addr = sprintf("239.255.42.%d", 42+$hdmi_dev);

my $src_ip = Sys::HostIP->new()->ip;

my $ipv4 = Net::Frame::Layer::IPv4->new(
  src => $src_ip,
  dst => '224.0.0.22',
  protocol => NF_IPv4_PROTOCOL_IGMP,
  flags => NF_IPv4_DONT_FRAGMENT,
  ttl => 1,
);

my $report =  Net::Frame::Layer::IGMP::v3Report->new(
   type         => NF_IGMP_REPORTv3TYPE_CHANGEEXCLUDE,
   auxDataLen       => 0,
   numSources       => 0,
   multicastAddress => $multicast_addr,
   sourceAddress    => [],
   auxData          => '',
   );

#my $igmp = Net::Frame::Layer::IGMP->new(
#   type         => NF_IGMP_TYPE_REPORTv3,
#   maxResp      => 0,
#   checksum     => 0,
#   groupAddress => '239.255.42.44',
#);

my $igmp = Net::Frame::Layer::IGMP->v3report(
   type         => NF_IGMP_TYPE_REPORTv3,
   maxResp      => 0,
   checksum     => 0,
   reserved     => 0,
   numGroupRecs => 1,
);

my $osimple = Net::Frame::Simple->new(
  layers => [$ipv4, $igmp, $report],
);

my $writer = Net::Write::Layer3->new(
  dst => '224.0.0.22',
  protocol => NW_IPPROTO_RAW,
  family => NW_AF_INET,
);

while(1) {
print "Sending multicast join\n";
$writer->open();
$osimple->send($writer);
$writer->close();
sleep 60;
}

#print Dumper(unpack("H*", $osimple->pack));
